@@ -70,7 +70,7 @@ class KScopeActions;
  */
 class KScope : public KParts::DockMainWindow
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	KScope(TQWidget* pParent = 0, const char* szName = 0);
